@@ -5,7 +5,6 @@ import asyncio
 import logging
 import struct
 from asyncio import IncompleteReadError, StreamReader, StreamWriter
-from typing import Dict
 
 from google.protobuf.message import DecodeError
 from google.protobuf.message import Message as ProtobufMessage
@@ -95,7 +94,10 @@ class Bridge:
         await self.cmd_close_session()
 
         # Wait for background task to finish
-        await self._read_task
+        try:
+            await self._read_task
+        except asyncio.CancelledError:
+            pass
 
     def is_connected(self) -> bool:
         """Returns True if the bridge is connected."""
@@ -222,7 +224,7 @@ class Bridge:
             except DecodeError as exc:
                 _LOGGER.error("Failed to decode message: %s", exc)
 
-    def cmd_start_session(self, take_over=False):
+    def cmd_start_session(self, take_over: bool = False):
         """Starts the session on the device by logging in and optionally disconnecting an already existing session."""
         _LOGGER.debug("StartSessionRequest")
         result = self._send(
@@ -250,7 +252,7 @@ class Bridge:
             zehnder_pb2.GatewayOperation.ListRegisteredAppsRequestType,
         )
 
-    def cmd_register_app(self, uuid, device_name, pin):
+    def cmd_register_app(self, uuid: str, device_name: str, pin: int):
         """Register a new app by specifying our own uuid, device_name and pin code."""
         _LOGGER.debug("RegisterAppRequest")
         return self._send(
@@ -259,11 +261,11 @@ class Bridge:
             {
                 "uuid": bytes.fromhex(uuid),
                 "devicename": device_name,
-                "pin": pin,
+                "pin": int(pin),
             },
         )
 
-    def cmd_deregister_app(self, uuid):
+    def cmd_deregister_app(self, uuid: str):
         """Remove the specified app from the registration list."""
         _LOGGER.debug("DeregisterAppRequest")
         if uuid == self._local_uuid:
